# Generated by Django 5.0.6 on 2024-07-18 08:47

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="UrlsTemplateView",
            fields=[
                ("id", models.AutoField(primary_key=True, serialize=False)),
                ("url", models.CharField(max_length=255)),
                ("template_name", models.CharField(max_length=255)),
            ],
            options={
                "verbose_name": "Map",
                "verbose_name_plural": "Map",
                "db_table": "django_urls_templateview",
                "ordering": ("url",),
                "unique_together": {("url", "template_name")},
            },
        ),
    ]
